"use client"
import React from 'react'
import { useSearchParams } from 'next/navigation'

const ProjectDetails = ({ 
  userName,
  developerSubUserName,
  developerSubUserRole,
  developerSubUserId,
  projectRole, 
  setProjectRole,
  projectName, 
  setProjectName,
  reraNo, 
  setReraNo,
  projectDescription, 
  setProjectDescription
}) => {
  const searchParams = useSearchParams();
  const subUserId = searchParams?.get('subuser');

  return (
    <div className='container mx-auto px-4 sm:px-6 lg:px-8 max-w-4xl'>
      <div className='flex flex-col gap-4 w-full'>
        {subUserId ? (
          <div className='space-y-2'>
            <p className='font-semibold text-2xl sm:text-3xl md:text-4xl'>
              Hello {developerSubUserName} !
            </p>
            <p className='text-sm text-gray-600'>
              Role: {developerSubUserRole}
            </p>
          </div>
        ) : (
          <p className='font-semibold text-2xl sm:text-3xl md:text-4xl'>
            Hello {userName} !
          </p>
        )}
        <p className='font-semibold text-base sm:text-lg text-tertiary'>
          Please Fill your Project Details
        </p>
        
        <div className='space-y-4'>
          {/* Project Name Input */}
          <div className='flex flex-col gap-2'>
            <label htmlFor="project-name" className='text-sm font-medium text-gray-700'>
              Project Name
            </label>
            <input 
              id="project-name"
              type="text"
              placeholder="Enter Project Name"
              value={projectName}
              onChange={(e) => setProjectName(e.target.value)}
              className='w-full px-3 py-2 border border-gray-300 rounded-md 
                         focus:outline-none focus:ring-2 focus:ring-brand 
                         text-sm sm:text-base 
                         transition-all duration-300 ease-in-out'
            />
          </div>

          {/* RERA No Input */}
          <div className='flex flex-col gap-2'>
            <label htmlFor="rera-no" className='text-sm font-medium text-gray-700'>
              RERA No
            </label>
            <input 
              id="rera-no"
              type="text"
              placeholder="Enter RERA Registration Number"
              value={reraNo}
              onChange={(e) => setReraNo(e.target.value)}
              className='w-full px-3 py-2 border border-gray-300 rounded-md 
                         focus:outline-none focus:ring-2 focus:ring-brand 
                         text-sm sm:text-base 
                         transition-all duration-300 ease-in-out'
            />
          </div>

          {/* Project Land Type */}
          <div className='flex flex-col gap-2'>
            <label className='text-sm font-medium text-gray-700'>
              Project Land Type
            </label>
            <div className="flex flex-wrap gap-2 sm:gap-4">
              {["Residential", "Commercial", "Industrial"].map(item => (
                <button 
                  key={item}
                  type="button"
                  onClick={() => setProjectRole(item)}
                  className={`
                    ${item === projectRole 
                      ? "text-white bg-brand" 
                      : "text-gray-700 border-[1px] border-tertiary"} 
                    rounded-lg py-1 px-3 
                    text-xs sm:text-sm 
                    transition-all duration-300 ease-in-out
                    hover:opacity-80 focus:outline-none focus:ring-2 focus:ring-brand
                  `}
                >
                  {item}
                </button>
              ))}
            </div>
          </div>

          {/* Project Description */}
          <div className='flex flex-col gap-2'>
            <label 
              htmlFor="project-description" 
              className='text-sm font-medium text-gray-700'
            >
              Project Description
            </label>
            <textarea 
              id="project-description"
              rows={5}
              placeholder="Enter project details..."
              value={projectDescription}
              onChange={(e) => setProjectDescription(e.target.value)}
              className='w-full px-3 py-2 
                         bg-[#F1F1F1] border-brand border-[1px] 
                         rounded-md 
                         focus:outline-none focus:ring-2 focus:ring-brand 
                         text-sm sm:text-base 
                         resize-y 
                         transition-all duration-300 ease-in-out'
            ></textarea>
          </div>
        </div>
      </div>
    </div>
  )
}

export default ProjectDetails